==> aws-cdk-scala-cognito_2.13-0.1.2-sources.jar: io/burkard/cdk/services/cognito/CfnIdentityPool.scala <==
package io.burkard.cdk.services.cognito

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnIdentityPool {

  def apply(
    internalResourceId: String,
    allowClassicFlow: Option[Boolean] = None,
    identityPoolName: Option[String] = None,
    allowUnauthenticatedIdentities: Option[Boolean] = None,
    pushSync: Option[software.amazon.awscdk.services.cognito.CfnIdentityPool.PushSyncProperty] = None,
    cognitoStreams: Option[software.amazon.awscdk.services.cognito.CfnIdentityPool.CognitoStreamsProperty] = None,
    supportedLoginProviders: Option[AnyRef] = None,
    openIdConnectProviderArns: Option[List[String]] = None,
    cognitoIdentityProviders: Option[List[_]] = None,
    cognitoEvents: Option[AnyRef] = None,
    samlProviderArns: Option[List[String]] = None,
    developerProviderName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.cognito.CfnIdentityPool =
    software.amazon.awscdk.services.cognito.CfnIdentityPool.Builder
      .create(stackCtx, internalResourceId)
      .allowClassicFlow(allowClassicFlow.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .identityPoolName(identityPoolName.orNull)
      .allowUnauthenticatedIdentities(allowUnauthenticatedIdentities.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .pushSync(pushSync.orNull)
      .cognitoStreams(cognitoStreams.orNull)
      .supportedLoginProviders(supportedLoginProviders.orNull)
      .openIdConnectProviderArns(openIdConnectProviderArns.map(_.asJava).orNull)
      .cognitoIdentityProviders(cognitoIdentityProviders.map(_.asJava).orNull)
      .cognitoEvents(cognitoEvents.orNull)
      .samlProviderArns(samlProviderArns.map(_.asJava).orNull)
      .developerProviderName(developerProviderName.orNull)
      .build()
}

==> aws-cdk-scala-cognito_2.13-0.3.0-sources.jar: io/burkard/cdk/services/cognito/CfnIdentityPool.scala <==
package io.burkard.cdk.services.cognito

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnIdentityPool {

  def apply(
    internalResourceId: String,
    allowUnauthenticatedIdentities: Boolean,
    allowClassicFlow: Option[Boolean] = None,
    identityPoolName: Option[String] = None,
    pushSync: Option[software.amazon.awscdk.services.cognito.CfnIdentityPool.PushSyncProperty] = None,
    cognitoStreams: Option[software.amazon.awscdk.services.cognito.CfnIdentityPool.CognitoStreamsProperty] = None,
    supportedLoginProviders: Option[AnyRef] = None,
    openIdConnectProviderArns: Option[List[String]] = None,
    cognitoIdentityProviders: Option[List[_]] = None,
    cognitoEvents: Option[AnyRef] = None,
    samlProviderArns: Option[List[String]] = None,
    developerProviderName: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.cognito.CfnIdentityPool =
    software.amazon.awscdk.services.cognito.CfnIdentityPool.Builder
      .create(stackCtx, internalResourceId)
      .allowUnauthenticatedIdentities(allowUnauthenticatedIdentities)
      .allowClassicFlow(allowClassicFlow.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .identityPoolName(identityPoolName.orNull)
      .pushSync(pushSync.orNull)
      .cognitoStreams(cognitoStreams.orNull)
      .supportedLoginProviders(supportedLoginProviders.orNull)
      .openIdConnectProviderArns(openIdConnectProviderArns.map(_.asJava).orNull)
      .cognitoIdentityProviders(cognitoIdentityProviders.map(_.asJava).orNull)
      .cognitoEvents(cognitoEvents.orNull)
      .samlProviderArns(samlProviderArns.map(_.asJava).orNull)
      .developerProviderName(developerProviderName.orNull)
      .build()
}
